@@ -4,10 +4,10 @@ import json
 import click
 import subprocess
 import requests
-import pandas as pd
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
+from itertools import islice
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
 OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
@@ -21,6 +21,7 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
+        print(raw_json)
         if self.command == "show running-config":
             first = True
             for line in raw_json.split('\n'):
@@ -35,30 +36,33 @@ class Network3Medusa():
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
-            first = True
-            parsed_json = json.dumps(raw_json)
-            chunks = pd.read_json(parsed_json, chunksize=6000000)
-            print("here")
-            for chunk in chunks:
-                if first:
-                    print("first chunk")
-                    self.add_file_to_hedera(chunk)
-                    print(chunk)
-                    first = False
-                else:
-                    print("next chunk")
-                    self.append_file_to_hedera(chunk)
-            if WEBEX_ROOM:
-                self.send_webex_notification()
-        
+            json_dict = json.loads(raw_json)
+            print(json_dict)
+            # first = True
+            # it = iter(json_dict)
+            # size = 6000
+            # for i in range(0, len(json_dict), size):
+            #     if first:
+            #         first = False
+            #         payload = yield {k:json_dict[k] for k in islice(it, size)}
+            #         self.add_file_to_hedera(payload)
+            #     else:
+            #         payload = yield {k:json_dict[k] for k in islice(it, size)}
+            #         self.append_file_to_hedera(payload)
+            # query = FileInfoQuery().setFileId(self.fileId)
+            # info = query.execute(self.client)
+            # print("File size according to `FileInfoQuery`: ", info.size)            
+            # if WEBEX_ROOM:
+            #     self.send_webex_notification()
+      
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
-    def add_file_to_hedera(self, chunk):
+    def add_file_to_hedera(self, raw_json):
         self.client = Client.forTestnet()
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        fileContents = chunk
+        fileContents = raw_json
         print(fileContents)
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
@@ -69,12 +73,11 @@ class Network3Medusa():
         info = query.execute(self.client)
         print("file: ",  self.fileId.toString())
         print("File size according to `FileInfoQuery`: ", info.size)
-
     def append_file_to_hedera(self, interface):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
                 .setContents(interface)
-                .setMaxChunks(2000)
+                .setMaxChunks(500)
                 .setMaxTransactionFee(Hbar(2))
                 .freezeWith(self.client))
         resp = tran.execute(self.client)
